import os
import sys
from datetime import datetime
import glob
from sys import argv
from jinja2 import Template
import shutil
import libcurses
from . import constantes_document_latex as constantes
from . import lib_nettoyage_argv as nettoyage
from . import lib_annee_scolaire as annee_scolaire

template_dir = constantes.jinja_template_dir
def documentex():
    """Script permettant de créer un dossier nommé numero_titre-dossier, numero ou titre dans lequel figurent les squelettes des fichiers latex correspondant au type de document demandé.
    Exemple d'utilisation :
        documentex 01_test td
    """

    if len(argv) != 3:
        print("usage : numero_nom-fichier type_document")
        quit()
    if nettoyage.arguments(argv[1]) is None:
        print("Le format du premier argument doit être de la forme numero_titre-dossier, numero ou titre")
        quit()

    # Initialisation des variables
    # contenu,tex_file,fancyhead,type_document,short_title,lycee,classe,title,auteur,semaine,liste_noms,td,ds_numero,annee
    date = datetime.now().strftime("%Y-%m-%d")
    nom_fichier = argv[1]
    numero,titre = nettoyage.arguments(nom_fichier)
    tex_file = constantes.tex_file # nom du fichier dans lequel on écrit du LaTeX
    type_document = argv[2]
    contenu,td,fancyhead,appartenance = constantes.dictionnaire_type_document[type_document]
    short_title = type_document.upper()+' '+numero
    title,semaine,nom1,nom2,nom3 = constantes.initialiser_variables() # c'est moche...
    auteur = constantes.auteur
    annee = annee_scolaire.annee_scolaire(True)
    institution = constantes.institution
    nom_institution = constantes.nom_institution
    lycee_adresse = constantes.lycee_adresse
    lycee_complement_adresse = constantes.lycee_complement_adresse
    auteur_lettre = constantes.auteur_lettre
    auteur_titre = constantes.auteur_titre
    auteur_adresse_mail = constantes.auteur_adresse_mail
    promotion = constantes.promotion

    if appartenance:
        classe = constantes.classe_appartenance
        lycee = constantes.lycee_appartenance
    else:
        classe = ''
        lycee = ''
    ds_numero = ''

    # Initialisation des variables suivant le type d'écrit
    if contenu:
        title = libcurses.saisie_message_std('Quel titre long pour ce document ? ')
        short_title = libcurses.saisie_message_std('Quel titre court pour ce document ? ')
    if type_document == 'dm':
        short_title += ' : à rendre pour le '
        short_title += libcurses.saisie_message_std('à rendre pour le : ? ')
    if type_document == 'cr':
        lycee = libcurses.saisie_message_std('Quel lycée ? ')
        classe = libcurses.saisie_message_std('Quelle classe ? ')
        semaine = libcurses.saisie_message_std('Quelle semaine ? ')
        nom1 = libcurses.saisie_message_std('Premier candidat ? ')
        nom2 = libcurses.saisie_message_std('Deuxième candidat ? ')
        nom3 = libcurses.saisie_message_std('Troisième candidat ? ')
    if type_document == 'ob':
        nom1 = libcurses.saisie_message_std('Nom du candidat ? ')

    try:
        os.makedirs(argv[1])
    except:
       continuer = libcurses.saisie_message_std(' Le dossier existe déjà ! Continuer ? (o/n) ')
       if continuer != 'o':
           quit()
       else:
           pass #le dossier existe déjà, on va ré-écrire les fichiers qui s'y trouvent
    try:
       os.makedirs(os.path.join(argv[1],'Utils'))
    except:
       pass #le dossier existe déjà, on va ré-écrire les fichiers qui s'y trouvent
    liste_noms = [nom1,
                  nom2,
                  nom3,
                 ]
    tex_file_path = nom_fichier
    ressource_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)),template_dir) # dossier des templates
    fichiers = glob.glob(os.path.join(ressource_dir,'*'))
    fichiers = [fichier for fichier in fichiers if 'Utils' not in fichier ]
    image = [fichier for fichier in fichiers if 'LW.png' in fichier][0] 
    fichiers.remove(image) #on enlève l'image LW.png des fichiers
    fichiers_utils = glob.glob(os.path.join(os.path.join(ressource_dir,'Utils'),'*'))

    if type_document in ['ds','let']:
        shutil.copy(image,os.path.join(tex_file_path,'LW.png'))
        if type_document == 'ds':
            ds_numero = constantes.dictionnaire_numero_ds[numero]
     ## attention mettre numéro épreuve (?)

    # Génération des fichiers de base
    for fichier in fichiers:
        nom_fichier = os.path.basename(fichier)
        with open(os.path.join(tex_file_path,nom_fichier),'w') as outfile:
                template = constantes.latex_jinja_env.get_template(os.path.abspath(fichier))
                outfile.write(template.render(date=date,contenu=contenu,tex_file=tex_file,fancyhead=fancyhead,type_ecrit=type_document,short_title=short_title,lycee=lycee,classe=classe,title=title,auteur=auteur,semaine=semaine,liste_noms=liste_noms,td=td,ds_numero=ds_numero,annee=annee,institution=institution,nom_institution=nom_institution,lycee_adresse=lycee_adresse,lycee_complement_adresse=lycee_complement_adresse,auteur_lettre=auteur_lettre,auteur_titre=auteur_titre,auteur_adresse_mail=auteur_adresse_mail,promotion=promotion))

    # Génération des fichiers Utils
    for fichier in fichiers_utils:
        nom_fichier = os.path.basename(fichier)
        with open(os.path.join(os.path.join(tex_file_path,'Utils'),nom_fichier),'w') as outfile:
            template = constantes.latex_jinja_env.get_template(os.path.abspath(fichier))
            outfile.write(template.render(date=date,contenu=contenu,tex_file=tex_file,fancyhead=fancyhead,type_ecrit=type_document,short_title=short_title,lycee=lycee,classe=classe,title=title,auteur=auteur,semaine=semaine,liste_noms=liste_noms,td=td,ds_numero=ds_numero,annee=annee,institution=institution,nom_institution=nom_institution,lycee_adresse=lycee_adresse,lycee_complement_adresse=lycee_complement_adresse,auteur_lettre=auteur_lettre,auteur_titre=auteur_titre,auteur_adresse_mail=auteur_adresse_mail,promotion=promotion))
    # Création du dossier de correction avec les fichiers pré-remplis
    fichiers = glob.glob(os.path.join(argv[1],'*'))
    fichiers = [fichier for fichier in fichiers if 'Utils' not in fichier ]
    if type_document in constantes.type_document_correction:
       os.makedirs(os.path.join(argv[1],'Correction'))
       shutil.copytree(os.path.join(argv[1],'Utils'),os.path.join(os.path.join(argv[1],'Correction'),'Utils'))
       for fichier in fichiers:
           shutil.copy(fichier,os.path.join(argv[1],'Correction'))
